=begin

Copyright 2009, Alexander C. Schreyer
All rights reserved

THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE.

License:        GPL

Author :        Alexander Schreyer, www.alexschreyer.net, mail@alexschreyer.net

Name :          NumberVertices
Version :       1.1
Date :          September 29, 2009

Description :   Select a face and get its vertice numbers and its normal vector
                displayed in a group

Usage :         This is for debugging purposes only. Don't use it on many faces
                at a time. It slows SU down.

History:        1.0 (9/21/2009) - first version
                1.1 (9/29/2009) - reformatted everything into module
                                - minor changes

=end

require 'sketchup.rb'

module AS_number_vertices

  def self.number_vertices

    # Get the active model
    model = Sketchup.active_model
    allentities = model.entities

    # Get currently selected objects
    selection_set = model.selection

    if selection_set.empty?
      UI.messagebox("Please select at least one face.")
      exit
    else
      # Do this for each face in the selection set seperately
      selection_set.each {|entity|
        model.start_operation($exStrings.GetString("Number vertices"))
        vert_num = 0
        group = allentities.add_group
        entities = group.entities
        if entity.typename == "Face"
          entity.vertices.each { |vertex|
            # If you only want the outer loop vertices, activate this instead:
            # entity.outer_loop.vertices.each { |vertex|
            t = entities.add_text(vert_num.to_s, vertex)
            vert_num += 1
          }
          t = entities.add_text("Normal: "+entity.normal.to_s, entity.bounds.center)
        end
        model.commit_operation
      }
    end

  end # number_vertices

end # module

if (!file_loaded?(__FILE__))

  # Add to the SketchUp tools menu
  tools_menu = UI.menu("Tools")
  tools_menu.add_item("Number Face Vertices") { AS_number_vertices::number_vertices }

  # Let Ruby know we have loaded this file
  file_loaded(__FILE__)

end
